* Author: Antonio Soares Martins Neto 
* email: martinsneto.as@gmail.com or asmartins@worldbank.org
* Last updated: 05/03/2024
* Stata version: 18
/*=======================================================================*/

set more off
clear *
set matsize 4000
set maxvar 12000
set seed 12345

*sysdir set PLUS "C:\Users\wb557793\OneDrive - WBG\FAT project (core)\02_codes\All_Countries\gender paper\Final code\ado"

/*=======================================================================*/
*Programs to install
/*
ssc install outreg
search estpost and install
ssc install coefplot
ssc install egenmore
ssc install ftools
ssc install reghdfe
ssc install psmatch2
ssc install estout
ssc install oaxaca
*/
/*=======================================================================*/


** Define directory and country
if c(username) == "wb549482" {
	/* The following line should contain the path to your do files */
	global path_dofile "C:\Users\wb549482\OneDrive - WBG\FAT_Gender_Gap\02_code"
	/* The following line should contain the path to your inpuit '.xlsx' file */
	global path_import "C:\Users\wb549482\OneDrive - WBG\2020_Technology_Adoption\01_data\All_Countries\02_dta"
	/* The following line should contain the path to your output files */
	global path_output "C:\Users\wb549482\OneDrive - WBG\FAT_Gender_Gap\03_output"
}

if c(username) == "wb557793" {
	/* The following line should contain the path to your do files */
	global path_dofile "C:\Users\wb557793\OneDrive - WBG\FAT project (core)\02_codes\All_Countries\gender paper\Final code"
	/* The following line should contain the path to your inpuit '.xlsx' file */
	global path_import "C:\Users\wb557793\OneDrive - WBG\FAT project (core)\02_codes\All_Countries\gender paper\Input"
	/* The following line should contain the path to your output files */
	global path_output "C:\Users\wb557793\OneDrive - WBG\FAT project (core)\02_codes\All_Countries\gender paper\Output_3"
	/* The following line should contain the path to your ado file */
	
}

use "${path_import}\TAS_All_Countries_With_Tech_Index_v11.dta"

drop if country == "Malawi" | country == "India" | country == "Bangladesh" | country == "Cambodia"
drop if country == "Brazil" & region != "BR_Ceara" 

global weight3 "base_ctr_wt"
global tech_ext_gbf_idx "max_b8a max_b9a max_b10a max_b11a max_b13b max_b14a max_b15a tech_max_gbf_firm" 
global tech_int_gbf_idx "int_b8b int_b9b int_b10a int_b11b int_b13c int_b14b int_b15b tech_int_gbf_firm" 
global digital "digit_admin digit_plan digit_sourc digit_market digit_sales digit_paym digit_qual"


gen Productivity = 1
replace Productivity = 0 if country == "Chile" | country == "Poland"  | country == "BurkinaFaso" // Define countries that we will use for productivity analysis

drop ownership incentives performance mq_index education experience experience_lc studied_abroad  mhc_index  share_college max_college R_and_D max_RD develop innovation_skills_index college_manager 


*===============================================================================
* Define indexes
*===============================================================================

do "${path_dofile}\1.Defining indexes.do" 

*===============================================================================
* Define dummy variables and digital technologies 
*===============================================================================

do "${path_dofile}\2.Dummy_variables.do" 

*===============================================================================
* Define other variables and survey design
*===============================================================================

do "${path_dofile}\3.Variable_construction_survey_design.do"

*===============================================================================
* Define subpopulations
*===============================================================================


gen Female = 0
replace Female = 1 if gender_management == 1

gen Male = 0 
replace Male = 1 if gender_management == 0


gen Food = 0
replace Food = 1 if a5a == 3

gen Food_Female = 0
replace Food_Female = 1 if Food == 1 & gender_management == 1

gen Food_Male = 0
replace Food_Male = 1 if Food == 1 & gender_management == 0


gen Retail = 0
replace Retail = 1 if a5a == 7

gen Retail_Female = 0
replace Retail_Female = 1 if Retail == 1 & gender_management == 1

gen Retail_Male = 0
replace Retail_Male = 1 if Retail == 1 & gender_management == 0

gen Apparel = 0
replace Apparel = 1 if a5a == 4

gen Apparel_Female = 0
replace Apparel_Female = 1 if Apparel == 1 & gender_management == 1

gen Apparel_Male = 0
replace Apparel_Male = 1 if Apparel == 1 & gender_management == 0

*===============================================================================
* Descriptives statistics
*===============================================================================

do "${path_dofile}\4. Descriptives.do" 

*===============================================================================
* Figures
*===============================================================================

do "${path_dofile}\5.Figures.do" 

*===============================================================================
* Regressions Adoption
*===============================================================================


do "${path_dofile}\6. Adoption.do" 

*===============================================================================
* Regressions FTM
*===============================================================================

do "${path_dofile}\7. Regressions.do" 

*===============================================================================
* Appendix C
*===============================================================================

do "${path_dofile}\8. Appendix C.do" 