
*===============================================================================
* Define regions and size group
*===============================================================================

gen size = size_group
label define size 1 "Small" 2 "Medium" 3 "Large", replace
label value size size

drop region
rename region_id region


*===============================================================================
* Create log of tech
*===============================================================================

foreach var of varlist tech_max_gbf_firm tech_int_gbf_firm tech_max_sbf_firm tech_int_sbf_firm  {
gen ln_`var' = log(`var')
}


foreach var of varlist  e3a e3b e3c e3d e3e e3f  {
replace `var' = 0 if `var' == .
}


replace e2a = e2
drop ln_tot_emp_2018 
gen  ln_tot_emp_2018 = ln(e1)

*===============================================================================
*SURVEY DESIGN
*===============================================================================

* Please check the total number of countries each time global database is updated
tab country ,m
cap drop cty
cap encode country, gen(cty)
la li cty
la de l_cty 1 "BRA" 2 "BFA" 3 "CHI" 4 "ETH" 5 "GEO" 6 "GHA" 7 "KEN" 8 "KOR" 9 "POL" 10 "SEN" 11 "VNM", add modify
la val cty l_cty
tab cty,m
global cty_l `" "BRA" "BFA" "CHI" "ETH" "GEO" "GHA" "KEN" "KOR" "POL"  "SEN" "VNM" "'


* SEN:Formal & SEN: Informal
cap drop country_formality
gen country_formality = country
replace country_formality = "SENFormal" if country=="Senegal" & formality==1
replace country_formality = "SENInformal" if country=="Senegal" & formality==2

tab country_formality,m
cap drop cty_formality
cap encode country_formality, gen(cty_formality)
la li cty_formality
la de l_cty_formality 1 "BRA" 2 "IND" 3 "SENFormal" 4 "SENInformal" 5 "VNM", add modify
la val cty_formality l_cty_formality
tab cty_formality,m

* sampling unit
duplicates report cty firm_id
sort cty firm_id
by cty: egen su_seq = seq()
cap drop sampling_unit
gen sampling_unit = cty*10000 + su_seq
la var sampling_unit "Sampling Unit"
codebook sampling_unit
drop su_seq

* strata: cty (2 digits) + s1a_rev (3 digits) + s1b_rev (1 digit) + s1c_rev (2 digit)
sort cty s1a_rev s1b_rev s1c_rev firm_id
gen str_cty = substr(string(100 + cty),2,2) if cty!=.
gen str_cty_formality = substr(string(100 + cty_formality),2,2) if cty_formality!=.
gen str_s1a = substr(string(1000 + s1a_rev),2,3) if s1a_rev!=.
gen str_s1b = string(s1b_rev) if s1b_rev!=.
gen str_s1c = substr(string(100 + s1c_rev),2,2) if s1c_rev!=.

* Strata (country, s1a_rev, s1b_rev, s1c_rev)
gen str_strata = str_cty + str_s1a + str_s1b + str_s1c if cty!=. & s1a_rev!=. & s1b_rev!=. & s1c_rev!=.
cap drop strata
gen strata = int(real(str_strata))
format strata %12.0f
codebook str_strata strata
la var strata "Strata (country, s1a_rev, s1b_rev, s1c_rev)"

* Strata (country+formality, s1a_rev, s1b_rev, s1c_rev)
gen str_strata_formality = str_cty_formality + str_s1a + str_s1b + str_s1c if cty_formality!=. & s1a_rev!=. & s1b_rev!=. & s1c_rev!=.
gen strata_formality = int(real(str_strata_formality))
format strata %12.0f
codebook str_strata_formality strata_formality
la var strata_formality "Strata (country+formality, s1a_rev, s1b_rev, s1c_rev)"

drop str_cty str_s1a str_s1b str_s1c str_cty_formality

*sampling weight
cap drop sampling_weight
gen sampling_weight = base_ctr_wt
la var sampling_weight "Samping Weight"
order strata sampling_unit sampling_weight // <- Survey design variables

svyset [pweight=sampling_weight], strata(strata) singleunit(scaled)
svy: tab country , count format(%12.0fc)

*===============================================================================
*Additional variables
*===============================================================================
recode formality (2=0)

replace a7a = 60 if a7a > 60 // Replace managers experience (in years) to 60 if larger than 60
replace a7d = 0 if a7d == 2 // Manager studied abroad
replace b5a = 0 if b5a == 2 // Internet access
replace d7b = 0 if d7b == 2 | d7b == . // Replace missings with zero for government support
gen family_buss = 0 // Define family business
replace family_buss = 1 if a4b == 1 | a4b == 2


replace d2d = 0 if d2d == 2 // Interaction with MNEs
replace d2d = 0 if d2d == .


replace tot_emp_2019 = tot_emp_2018 if tot_emp_2019 == . 
gen log_employment = log(tot_emp_2019)
replace tot_emp_2019 = tot_emp_2018 if tot_emp_2019 == . 
gen emp_growth = (ln_tot_emp - ln_tot_emp_bf)/2 // Employment growth


*---------------------------*
*Define country, sector, regions, and sector-region dummies
*---------------------------*

egen sector_region = group(a5a region)
tab country, gen(cty_)
tab a5a, gen(sector_)
tab region, gen(region_)

*---------------------------*
*Define finance constraint
*---------------------------*

gen finance_constraint = .
replace finance_constraint = 0 if d3a == 2 & d3c == 0 // Didn't have a loan in the period and didn't have problems trying
replace finance_constraint = 0 if d3a == 1 & d3c == 0 // Had a loan and didn't have problems trying
replace finance_constraint = 1 if d3a == 2 & d3c > 0 // Didn't have a loan and had problems 
replace finance_constraint = 1 if d3a == 1 & d3c > 0 // Had a loan and had problems


*---------------------------*
*Define ownership and management variables
*---------------------------*

gen gender_ownership = .
replace gender_ownership = 1 if a4e == 1
replace gender_ownership = 0 if a4e == 2

gen gender_management = .
replace gender_management = 1 if a7b == 1
replace gender_management = 0 if a7b == 2

gen gender_ownership_intensive = .
replace gender_ownership_intensive = 1 if gender_ownership == 1 & a4f > 50 & a4f != .
replace gender_ownership_intensive = 0 if gender_ownership == 0
replace gender_ownership_intensive = 0 if gender_ownership == 1 & a4f <= 50 & a4f >=0
replace gender_ownership_intensive = . if inlist(country, "BurkinaFaso", "Chile", "Ethiopia", "Georgia", "Ghana", "Kenya", "Korea")


*===============================================================================
*Labels
*===============================================================================


label define size_group 1 "Small" 2 "Medium" 3 "Large", replace
label value size_group size_group

drop age
rename fage_group_id age
destring age, replace
label define age 1 "Age 0 to 5" 2 "Age 6 to 10" 3 "Age 11 to 15" 4 "Age 16 or more", replace
label value age age

label var ln_tech_max_gbf_firm "GBFs - Extensive margin"
label var ln_tech_max_sbf_firm "SBFs - Extensive margin"
label var ln_tech_int_gbf_firm "GBFs - Intensive margin"
label var ln_tech_int_sbf_firm "SBFs - Intensive margin"


label var log_employment "Log(Employment)"
label var tot_emp_2019 "Number of employees"
label var b5a "Internet connection"
label var d7b "Government support"
label var d2d "Interaction with MNEs"
label var family_buss "Family Business"
label var mnc_group "Multinational"
label var exp_group "Exporter"
label var e5d "Share of workers with college education"
label var a7a "Top manager years of experience"
label var a7d "Manager studied abroad" 

label var finance_constraint "Financial constraints"
label var ownership "Non-Family company"
label var incentives "Formal incentives"
label var performance "Performance indicators"
label var college_manager "Manager's with college"
label var a7a "Manager's experience (years)"
label var experience_lc "Experience in large company"
label var studied_abroad "Studied abroad"
label var share_college "Share of college-educated employees"
label var R_and_D "Share of R\&D employees"
label var develop "Innovation"
label var formality "Formality"

label var sector_1 "Crops"
label var sector_2 "Livestock"
label var sector_3 "Food Processing"
label var sector_4 "Apparel"
label var sector_5 "Motor Vehicles"
label var sector_6 "Pharmaceuticals"
label var sector_7 "Wholesale or retail"
label var sector_8 "Financial services"
label var sector_9 "Land transport" 
label var sector_10 "Health services"
label var sector_11 "Leather"    
label var sector_12 "Accommodation"  
label var sector_13 "Other Manufact."
label var sector_14 "Other Services" 

label var digit_admin "Digital - Business Administration"
label var digit_plan "Digital - Production Planning"
label var digit_sourc "Digital - Sourcing"
label var digit_market "Digital - Marketing"
label var digit_sales "Digital - Sales"
label var digit_paym "Digital - Payment"
label var digit_qual "Digital - Quality Control"

label	var	d_b8a1	"Handwritten processes"
label	var	d_b8a2	"Computers with standard software"
label	var	d_b8a3	"Mobile Apps or digital platforms"
label	var	d_b8a4	"Computers with specialized software"
label	var	d_b8a5	"Enterprise Resource Planning (ERP) "
label	var	d_b9a1	"Handwritten processes"
label	var	d_b9a2	"Computers with standard software"
label	var	d_b9a3	"Mobile Apps or digital platforms"
label	var	d_b9a4	"Specialized software for production"
label	var	d_b9a5	"Enterprise Resource Planning (ERP)"
label	var	d_b10a1	"Manual search of suppliers"
label	var	d_b10a2	"Management of supply chain information using PCs"
label	var	d_b10a3	"Online social media, specialized Apps or digital platforms"
label	var	d_b10a4	"Supplier Relation Management (SRM)"
label	var	d_b10a5	"Supplier Relation Management (SRM) integrated g"
label	var	d_b11a1	"Face-to-face chat"
label	var	d_b11a2	"Online chat (e.g. Whatsapp or Internet)"
label	var	d_b11a3	"Structured surveys by phone, face-to-face, online, etc"
label	var	d_b11a4	"Customer Relationship Management software (CRM) "
label	var	d_b11a5	"Big data Analytics or Machine learning "
label	var	d_b13b1	"Sales at the establishment's premises"
label	var	d_b13b2	"Sales by phone, email orders, or sales representatives"
label	var	d_b13b3	"Sales through social media platforms or apps"
label	var	d_b13b4	"External digital platforms"
label	var	d_b13b5	"Online sales (e-commerce) using its own website"
label	var	d_b13b6	"Electronic orders integrated to SCM system"
label	var	d_b14a1	"Exchange of goods"
label	var	d_b14a2	"Cash"
label	var	d_b14a3	"Cheque, voucher, or bank wire at the branch"
label	var	d_b14a4	"Prepaid card, Debit card, or Credit card"
label	var	d_b14a5	"Online or eletronic payment through a bank wire"
label	var	d_b14a6	"Online payment through platform"
label	var	d_b14a7	"Virtual or Cryptocurrency"
label	var	d_b15a1	"Manual, visual, or written processes"
label	var	d_b15a2	"Human inspection assisted by computers or phones"
label	var	d_b15a3	"Statistical process control"
label	var	d_b15a4	"Automated systems"

label	var	db8b_int1	"Handwritten processes"
label	var	db8b_int2	"Computers with standard software"
label	var	db8b_int3	"Mobile Apps or digital platforms"
label	var	db8b_int4	"Computers with specialized software"
label	var	db8b_int5	"Enterprise Resource Planning (ERP)"
label	var	db9b_int1	"Handwritten processes"
label	var	db9b_int2	"Computers with standard software"
label	var	db9b_int3	"Mobile Apps or digital platforms"
label	var	db9b_int4	"Specialized software for production"
label	var	db9b_int5	"Enterprise Resource Planning (ERP)"
label	var	db10a_int1	"Manual search of suppliers"
label	var	db10a_int2	"Management of supply chain information using PCs"
label	var	db10a_int3	"Online social media, specialized Apps or digital platforms"
label	var	db10a_int4	"Supplier Relation Management (SRM)"
label	var	db10a_int5	"Supplier Relation Management (SRM) integrated"
label	var	db11b_int1	"Face-to-face chat"
label	var	db11b_int2	"Online chat (e.g. Whatsapp or Internet)"
label	var	db11b_int3	"Structured surveys by phone, face-to-face, online, etc"
label	var	db11b_int4	"Customer Relationship Management software (CRM)"
label	var	db11b_int5	"Big data Analytics or Machine learning"
label	var	db13c_int1	"Sales at the establishment's premises"
label	var	db13c_int2	"Sales by phone, email orders, or sales representatives"
label	var	db13c_int3	"Sales through social media platforms or apps"
label	var	db13c_int4	"External digital platforms"
label	var	db13c_int5	"Online sales (e-commerce) using its own website"
label	var	db13c_int6	"Electronic orders integrated to SCM system"
label	var	db14b_int1	"Exchange of goods"
label	var	db14b_int2	"Cash"
label	var	db14b_int3	"Cheque, voucher, or bank wire at the branch"
label	var	db14b_int4	"Prepaid card, Debit card, or Credit card"
label	var	db14b_int5	"Online or eletronic payment through a bank wire"
label	var	db14b_int6	"Online payment through platform"
label	var	db14b_int7	"Virtual or Cryptocurrency"
label	var	db15b_int1	"Manual, visual, or written processes"
label	var	db15b_int2	"Human inspection assisted by computers or phones"
label	var	db15b_int3	"Statistical process control"
label	var	db15b_int4	"Automated systems"



label var lnvapw "Log(Labor Productivity)"
label var emp_growth "Employment Growth"


label var gender_management "Female Top Manager"
label var gender_ownership "Female Ownership"
label var gender_ownership_intensive "Female Ownership (intensive)"
