*===============================================================================
* Table 1 and Table 2
*===============================================================================
preserve
replace gender_management = gender_management*100
estpost tabstat gender_management [aw = $weight3], s(mean N)  by(country) columns(statistics)
esttab . using "${path_output}\Tables\Table1.tex", replace ////
 cells("mean(fmt(%6.2fc)) count(fmt(%6.0fc)) ") nonumber ///
  nomtitle nonote noobs label booktabs ///
  collabels("Share of FTMs" "Total Observations")
restore

preserve
replace gender_management = gender_management*100
estpost tabstat gender_management  [aw = $weight3], s(mean N) by(a5a) columns(statistics)
esttab . using "${path_output}\Tables\Table2.tex", replace label ////
 cells("mean(fmt(%6.2fc)) count(fmt(%6.0fc)) ") nonumber varlabels(`e(labels)') ///
  nomtitle nonote noobs booktabs ///
  collabels("Share of FTMs" "Total Observations")
  
  
restore

*===============================================================================
* Table 5
*===============================================================================

global gbf_tech "tech_max_gbf_firm tech_int_gbf_firm tech_max_sbf_firm tech_int_sbf_firm"

label var tech_max_gbf_firm "GBF - EXT"
label var tech_int_gbf_firm "GBF - INT"
label var tech_max_sbf_firm "SBF - EXT"
label var tech_int_sbf_firm "SBF - INT"

gen n = 1
bysort gender_management: egen Observations = sum(1)
label var Observations "Observations"


mata: mata clear

local i = 1

foreach var in $gbf_tech {

svy: reg `var' i.gender_management
outreg, keep(1.gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(unconditional) append(row`i') ctitles("", Difference) ///
store(unconditional) note("")  bdec(2) 
 
svy: reg `var' i.gender_management i.country_code
outreg, keep(1.gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(conditional) append(row`i') ctitles("", Difference) ///
 store(conditional) note("")  bdec(2) 

svy: reg `var' i.gender_management i.country_code i.a5a i.size_group
outreg, keep(1.gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(diff) append(row`i') ctitles("", Difference) ///
 store(diff) note("")  bdec(2) 

local ++i
}

outreg, replay(unconditional) merge(conditional)
outreg, replay(unconditional) merge(diff)

* Summary statistics

local count: word count $gbf_tech
mat sumstat = J(`count',4,.)

local i = 1

foreach var in $gbf_tech {

svy, subpop(Male): mean `var'
estat sd 
mat sumstat[`i',1] = r(mean) 
mat sumstat[`i',2] = r(sd)

svy, subpop(Female): mean `var' 
estat sd
mat sumstat[`i',3] = r(mean) 
mat sumstat[`i',4] = r(sd)
local i = `i' + 1

}

frmttable, statmat(sumstat) store(sumstat) sfmt(f,f,f,f) sdec(2)

outreg using "${path_output}/Tables/Table5", ///
replay(sumstat) merge(unconditional) bdec(2) tex nocenter note("") fragment plain replace  ///
ctitles("", Male, "", "Female", "", "", ""\ "", Mean,  SD, Mean, SD, Uncond.,Cond.,Cond.)  starlevels(10 5 1)


*===============================================================================
* Table 4 and Table B2
*===============================================================================

gen buss = 0
gen produc = 0
gen sourcing = 0 
gen marketing = 0
gen salesm = 0
gen payment = 0
gen quality = 0

label var buss "Business Administration"
label var produc "Production Planning"
label var sourcing "Supply Chain Management"
label var marketing "Marketing"
label var salesm "Sales Methods"
label var payment "Payment Methods"
label var quality "Quality Control"

global gbf_tech "buss d_b8a4 d_b8a5 produc d_b9a4 d_b9a5 sourcing d_b10a4 d_b10a5 marketing d_b11a4 d_b11a5 salesm d_b13b4 d_b13b5 d_b13b6 payment d_b14a5 d_b14a6 d_b14a7 quality d_b15a3 d_b15a4"


mata: mata clear

local i = 1

foreach var in $gbf_tech {

svy: reg `var' gender_management
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(unconditional) append(row`i') ctitles("", Difference) ///
 store(unconditional) note("")  bdec(2) 
 
svy: reg `var' gender_management i.country_code
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(conditional) append(row`i') ctitles("", Difference) ///
 store(conditional) note("")  bdec(2) 

	
svy: reg `var' gender_management i.country_code i.a5a i.size_group
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(diff) append(row`i') ctitles("", Difference) ///
 store(diff) note("")  bdec(2) 

 
local ++i
}

outreg, replay(unconditional) merge(conditional)
outreg, replay(unconditional) merge(diff)

* Summary statistics

local count: word count $gbf_tech
mat sumstat = J(`count',4,.)

local i = 1

foreach var in $gbf_tech {

svy, subpop(Male): mean `var'
estat sd 
mat sumstat[`i',1] = r(mean) 
mat sumstat[`i',2] = r(sd)

svy, subpop(Female): mean `var' 
estat sd
mat sumstat[`i',3] = r(mean) 
mat sumstat[`i',4] = r(sd)
local i = `i' + 1

}

*** Table 4

frmttable, statmat(sumstat) store(sumstat) sfmt(f,f,f,f) sdec(2)

outreg using "${path_output}/Tables/Table4", ///
replay(sumstat) merge(unconditional) bdec(2) tex nocenter note("") fragment plain replace  ///
ctitles("", Male, "", "Female", "", ""\ "", Mean,  SD, Mean, SD, Uncond.,Cond.)  starlevels(10 5 1)


global gbf_tech_int "buss db8b_int4 db8b_int5 produc db9b_int4 db9b_int5 sourcing db10a_int4 db10a_int5 marketing db11b_int4 db11b_int5 salesm db13c_int4 db13c_int5 db13c_int6 payment db14b_int4 db14b_int5 db14b_int6 db14b_int7 quality db15b_int3 db15b_int4"


mata: mata clear

local i = 1

foreach var in $gbf_tech_int {

svy: reg `var' gender_management
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(unconditional) append(row`i') ctitles("", Difference) ///
 store(unconditional) note("")  bdec(2) 
 
svy: reg `var' gender_management i.country_code
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(conditional) append(row`i') ctitles("", Difference) ///
 store(conditional) note("")  bdec(2) 

	
svy: reg `var' gender_management i.country_code i.a5a i.size_group
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(diff) append(row`i') ctitles("", Difference) ///
 store(diff) note("")  bdec(2) 

 
local ++i
}

outreg, replay(unconditional) merge(conditional)
outreg, replay(unconditional) merge(diff)

* Summary statistics

local count: word count $gbf_tech_int
mat sumstat = J(`count',4,.)

local i = 1

foreach var in $gbf_tech_int {

svy, subpop(Male): mean `var'
estat sd 
mat sumstat[`i',1] = r(mean) 
mat sumstat[`i',2] = r(sd)

svy, subpop(Female): mean `var' 
estat sd
mat sumstat[`i',3] = r(mean) 
mat sumstat[`i',4] = r(sd)
local i = `i' + 1

}

* Table B2

frmttable, statmat(sumstat) store(sumstat) sfmt(f,f,f,f) sdec(2)

outreg using "${path_output}/Tables/TableB2", ///
replay(sumstat) merge(unconditional) bdec(2) tex nocenter note("") fragment plain replace  ///
ctitles("", Male, "", "Female", "", ""\ "", Mean,  SD, Mean, SD, Uncond.,Cond.)  starlevels(10 5 1)

*===============================================================================
* Table 3
*===============================================================================

global DESCVARS "lnvapw tot_emp_2019 mnc_group exp_group d2d d7b mq_index ownership incentives performance mhc_index college_manager a7a experience_lc studied_abroad innovation_skills_index share_college R_and_D develop"

mata: mata clear

local i = 1

foreach var in $DESCVARS {

svy: reg `var' gender_management
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(unconditional) append(row`i') ctitles("", Difference) ///
 store(unconditional) note("")  bdec(2) 
 
svy: reg `var' gender_management i.country_code
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(conditional) append(row`i') ctitles("", Difference) ///
 store(conditional) note("")  bdec(2) 

	
svy: reg `var' gender_management i.country_code i.a5a i.size_group
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(diff) append(row`i') ctitles("", Difference) ///
 store(diff) note("")  bdec(2) 

 
local ++i
}

outreg, replay(unconditional) merge(conditional)
outreg, replay(unconditional) merge(diff)

* Summary statistics

local count: word count $DESCVARS
mat sumstat = J(`count',6,.)

local i = 1

foreach var in $DESCVARS {
	
svy: mean `var'
estat sd 
mat sumstat[`i',1] = r(mean) 
mat sumstat[`i',2] = r(sd)

svy, subpop(Male): mean `var'
estat sd 
mat sumstat[`i',3] = r(mean) 
mat sumstat[`i',4] = r(sd)

svy, subpop(Female): mean `var' 
estat sd
mat sumstat[`i',5] = r(mean) 
mat sumstat[`i',6] = r(sd)
local i = `i' + 1


}

frmttable, statmat(sumstat) store(sumstat) sfmt(f,f,f,f,f,f) sdec(2)

outreg using "${path_output}/Tables/Table3", ///
replay(sumstat) merge(unconditional) bdec(2) tex nocenter note("") fragment plain replace  ///
ctitles("", All, "", Male, "", "Female", "","Difference"\ "", Mean,  SD, Mean, SD, Mean, SD, Uncond.,Cond.,Cond.)  starlevels(10 5 1)


**************************************************************************************************************************************************************************
************************************************************** SBFs for food processing***********************************************************************************
**************************************************************************************************************************************************************************

*===============================================================================
* Table B4
*===============================================================================

gen input = 0
gen mixing = 0
gen bacterial = 0 
gen packaging = 0
gen storage = 0

global sbf_food "input d_c3_1b3 d_c3_1b4 mixing d_c3_2b3 d_c3_2b4 bacterial d_c3_3b3 d_c3_3b4 packaging d_c3_4b3 d_c3_4b4 storage d_c3_5b3 d_c3_5b4"

label var input "Input Testing"
label var mixing "Mixing/blending/cooking"
label var bacterial "Anti-bacterial processes"
label var packaging "Packaging"
label var storage "Food storage"

label	var	d_c3_1b1	"Sensory systems (e.g. visual, smell)"
label	var	d_c3_1b2	"Review of supplier testing"
label	var	d_c3_1b3	"Non-computer-controlled testing kits"
label	var	d_c3_1b4	"Computer testing"
label	var	d_c3_2b1	"Manual process"
label	var	d_c3_2b2	"Mechanical equipment requiring human force"
label	var	d_c3_2b3	"Power equipment requiring routine human interaction"
label	var	d_c3_2b4	"Power equipment controlled by computers or robotics"
label	var	d_c3_3b1	"Minimal-processing preservation methods"
label	var	d_c3_3b2	"Anti-bacterial wash or soaking"
label	var	d_c3_3b3	"Thermal Processing Technologies"
label	var	d_c3_3b4	"Advanced methods (e.g, High-pressure processing)"
label	var	d_c3_4b1	"Manual packing in bags, bottles or boxes"
label	var	d_c3_4b2	"Human operated mechanical equipment"
label	var	d_c3_4b3	"Power equipment requiring routine human interaction"
label	var	d_c3_4b4	"Power equipment controlled by computers or robotics"
label	var	d_c3_5b1	"Minimal protection with some exposure"
label	var	d_c3_5b2	"Ambient conditions in closed building"
label	var	d_c3_5b3	"Some climate control in secured building"
label	var	d_c3_5b4	"Fully automated climate and security-controlled"

mata: mata clear

local i = 1

foreach var in $sbf_food {
	
svy: reg `var' gender_management
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(unconditional) append(row`i') ctitles("", Difference) ///
 store(unconditional) note("")  bdec(2) 
 
svy: reg `var' gender_management i.country_code
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(conditional) append(row`i') ctitles("", Difference) ///
 store(conditional) note("")  bdec(2) 

	
svy: reg `var' gender_management i.country_code i.a5a i.size_group
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(diff) append(row`i') ctitles("", Difference) ///
 store(diff) note("")  bdec(2) 

 
local ++i
}

outreg, replay(unconditional) merge(conditional)
outreg, replay(unconditional) merge(diff)


* Summary statistics

local count: word count $sbf_food 
mat sumstat = J(`count',4,.)

local i = 1

foreach var in $sbf_food  {

svy, subpop(Food_Male): mean `var' 
estat sd
mat sumstat[`i',1] = r(mean) 
mat sumstat[`i',2] = r(sd)

svy, subpop(Food_Female): mean `var' 
estat sd
mat sumstat[`i',3] = r(mean) 
mat sumstat[`i',4] = r(sd)
local i = `i' + 1


}

frmttable, statmat(sumstat) store(sumstat) sfmt(f,f,f,f) sdec(2)

outreg using "${path_output}/Tables/TableB4", ///
replay(sumstat) merge(unconditional) bdec(2) tex nocenter note("") fragment plain replace  ///
ctitles("", Male, "", "Female", "", ""\ "", Mean,  SD, Mean, SD, Uncond.,Cond.)  starlevels(10 5 1)


drop input mixing bacterial packaging storage

**************************************************************************************************************************************************************************
************************************************************** SBFs for retail *******************************************************************************************
**************************************************************************************************************************************************************************

*===============================================================================
* Table B6
*===============================================================================

gen customer = 0
gen pricing = 0
gen merchan = 0 
gen inventory = 0
gen advertisement = 0

global sbf_retail "customer d_c7_1b3 d_c7_1b4 d_c7_1b5 pricing d_c7_2b4 d_c7_2b5 merchan d_c7_3b3 d_c7_3b4 inventory d_c7_4b4 d_c7_4b5 advertisement d_c7_5b4 d_c7_5b5 d_c7_5b6"

label var customer "Customer service"
label var pricing "Pricing"
label var merchan "Merchandising"
label var inventory "Inventory"
label var advertisement "Advertisement"

label	var	d_c7_1b1	"At the Store"
label	var	d_c7_1b2	"Phone call or call Help Desk"
label	var	d_c7_1b3	"Social Media"
label	var	d_c7_1b4	"Online requests"
label	var	d_c7_1b5	"Chatbots"
label	var	d_c7_2b1	"Manual Cost"
label	var	d_c7_2b2	"Automated markup"
label	var	d_c7_2b3	"Automated promotional"
label	var	d_c7_2b4	"Dynamic pricing systems "
label	var	d_c7_2b5	"Personalized pricing driven by predictive analytics"
label	var	d_c7_3b1	"Manually selecting products"
label	var	d_c7_3b2	"Category Management tools"
label	var	d_c7_3b3	"Retail Merchandising Systems or Digital Merchandising"
label	var	d_c7_3b4	"Product trend analytics"
label	var	d_c7_4b1	"Handwritten record keeping"
label	var	d_c7_4b2	"Computer databases with manual updates"
label	var	d_c7_4b3	"Warehouse Management System with specialized software"
label	var	d_c7_4b4	"Automated inventory control (CAO)"
label	var	d_c7_4b5	"Automated Storage and Retrieval systems (AS/RS)"
label	var	d_c7_5b1	"Paper based communication"
label	var	d_c7_5b2	"Radio, Billboards, TV"
label	var	d_c7_5b3	"Email or mobile phone"
label	var	d_c7_5b4	"Social Media"
label	var	d_c7_5b5	"Search Engine Marketing"
label	var	d_c7_5b6	"Big data Analytics or Artificial Intelligence"

mata: mata clear

local i = 1

foreach var in $sbf_retail {

svy: reg `var' gender_management
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(unconditional) append(row`i') ctitles("", Difference) ///
 store(unconditional) note("")  bdec(2) 
 
svy: reg `var' gender_management i.country_code
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(conditional) append(row`i') ctitles("", Difference) ///
 store(conditional) note("")  bdec(2) 

	
svy: reg `var' gender_management i.country_code i.a5a i.size_group
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(diff) append(row`i') ctitles("", Difference) ///
 store(diff) note("")  bdec(2) 

 
local ++i
}

outreg, replay(unconditional) merge(conditional)
outreg, replay(unconditional) merge(diff)

* Summary statistics

local count: word count $sbf_retail 
mat sumstat = J(`count',4,.)

local i = 1

foreach var in $sbf_retail  {

svy, subpop(Retail_Male): mean `var' 
estat sd
mat sumstat[`i',1] = r(mean) 
mat sumstat[`i',2] = r(sd)

svy, subpop(Retail_Female): mean `var' 
estat sd
mat sumstat[`i',3] = r(mean) 
mat sumstat[`i',4] = r(sd)
local i = `i' + 1

}

frmttable, statmat(sumstat) store(sumstat) sfmt(f,f,f,f) sdec(2)

outreg using "${path_output}/Tables/TableB6", ///
replay(sumstat) merge(unconditional) bdec(2) tex nocenter note("") fragment plain replace  ///
ctitles("", Male, "", "Female", "", ""\ "", Mean,  SD, Mean, SD, Uncond.,Cond.)  starlevels(10 5 1)

drop customer pricing merchan inventory advertisement


**************************************************************************************************************************************************************************
************************************************************** SBFs for apparel *******************************************************************************************
**************************************************************************************************************************************************************************

*===============================================================================
* Table B5
*===============================================================================

gen design = 0
gen cutting = 0
gen sewing  = 0 
gen ironing = 0

global sbf_apparel "design d_c4_1b3 cutting d_c4_2b4 d_c4_2b5 sewing d_c4_3b4 d_c4_3b5 ironing d_c4_4b4 d_c4_4b5"

label var design "Design"
label var cutting "Cutting"
label var sewing "Sewing"
label var ironing "Ironing"

label	var	d_c4_1b1	"Manual design and hand drawing"
label	var	d_c4_1b2	"Digital or semi-digital design using specialized 2D drawing software"
label	var	d_c4_1b3	"Computer Aided Design (CAD) or 3D design"

label	var	d_c4_2b1	"Manual cutting"
label	var	d_c4_2b2	"Cutting machine manually operated"
label	var	d_c4_2b3	"Semi-Automatic cutting machine"
label	var	d_c4_2b4	"Automatic or Computerized cutting machine"
label	var	d_c4_2b5	"Automatic/Computerized cutting machine (Laser)"

label	var	d_c4_3b1	"Manually sewing"
label	var	d_c4_3b2	"Machine sewing manually operated"
label	var	d_c4_3b3	"Semi-automated sewing machines"
label	var	d_c4_3b4	"Automated sewing machines"
label	var	d_c4_3b5	"3D Knitting"

label	var	d_c4_4b1	"Basic manual ironing"
label	var	d_c4_4b2	"Electric high-pressure steam iron"
label	var	d_c4_4b3	"Tunnel finisher"
label	var	d_c4_4b4	"Form finishing machine"
label	var	d_c4_4b5	"High tech pressing machine"


mata: mata clear

local i = 1

foreach var in $sbf_apparel {

svy: reg `var' gender_management
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(unconditional) append(row`i') ctitles("", Difference) ///
 store(unconditional) note("")  bdec(2) 
 
svy: reg `var' gender_management i.country_code
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(conditional) append(row`i') ctitles("", Difference) ///
 store(conditional) note("")  bdec(2) 

	
svy: reg `var' gender_management i.country_code i.a5a i.size_group
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(diff) append(row`i') ctitles("", Difference) ///
 store(diff) note("")  bdec(2) 

 
local ++i
}

outreg, replay(unconditional) merge(conditional)
outreg, replay(unconditional) merge(diff)


* Summary statistics

local count: word count $sbf_apparel
mat sumstat = J(`count',4,.)

local i = 1

foreach var in $sbf_apparel  {

svy, subpop(Apparel_Male): mean `var' 
estat sd
mat sumstat[`i',1] = r(mean) 
mat sumstat[`i',2] = r(sd)

svy, subpop(Apparel_Female): mean `var' 
estat sd
mat sumstat[`i',3] = r(mean) 
mat sumstat[`i',4] = r(sd)
local i = `i' + 1

}

frmttable, statmat(sumstat) store(sumstat) sfmt(f,f,f,f) sdec(2)

outreg using "${path_output}/Tables/TableB5", ///
replay(sumstat) merge(unconditional) bdec(2) tex nocenter note("") fragment plain replace  ///
ctitles("", Male, "", "Female", "", ""\ "", Mean,  SD, Mean, SD, Uncond.,Cond.)  starlevels(10 5 1)

drop design cutting sewing ironing


**************************************************************************************************************************************************************************
************************************************************** SBFs for agriculture *******************************************************************************************
**************************************************************************************************************************************************************************

*===============================================================================
* Table B3
*===============================================================================

gen Agriculture = 0
replace Agriculture = 1 if a5a == 1

gen Agriculture_Female = 0
replace Agriculture_Female = 1 if Agriculture == 1 & gender_management == 1

gen Agriculture_Male = 0
replace Agriculture_Male = 1 if Agriculture == 1 & gender_management == 0


gen land = 0
gen irrigation = 0
gen pest  = 0 
gen harvesting = 0
gen storage = 0
gen packing = 0

global sbf_agriculture "land d_c1_1b3 d_c1_1b4 irrigation d_c1_2b5 d_c1_2b6 pest d_c1_3b4 d_c1_3b5 harvesting d_c1_4b4 d_c1_4b5 storage d_c1_5b4 d_c1_5b5 packing d_c1_6b3 d_c1_6b4"

label var land "Land Preparation"
label var irrigation  "Irrigation"
label var pest "Pest control"
label var harvesting "Harvesting"
label var storage "Storage"
label var packing "Packing"

label	var	d_c1_1b1	"Manual plowing"
label	var	d_c1_1b2	"Animal Aided Instruments"
label	var	d_c1_1b3	"Tractors, motor tillers, rotators"
label   var d_c1_1b4    "Equipment with digital enabled technologies "

label	var	d_c1_2b1	"Rain-fed"
label	var	d_c1_2b2	"Manual irrigation "
label	var	d_c1_2b3	"Surface Flood Irrigation by Gravity"
label	var	d_c1_2b4	"Irrigation by Small Pump"
label	var	d_c1_2b5	"Drip irrigation"
label	var	d_c1_2b6	"Automated system controlled by sensors"

label	var	d_c1_3b1	"Manual application of pesticide"
label	var	d_c1_3b2	"Mechanical application of pesticide "
label	var	d_c1_3b3	"Biological methods "
label	var	d_c1_3b4	"Fully-automated Variable Rate Application (VRA)"
label	var	d_c1_3b5	"Advanced Precision Agriculture"

label	var	d_c1_4b1	"Manual"
label	var	d_c1_4b2	"Animal Aided Instruments"
label	var	d_c1_4b3	"Human-operated machines"
label	var	d_c1_4b4	"Mechanized process with machines or tractors"
label	var	d_c1_4b5	"Automated process with machines or tractors"

label	var	d_c1_5b1	"Precarious facility"
label	var	d_c1_5b2	"Storage facilities without controlled temperature"
label	var	d_c1_5b3	"Facilities with cold or dry controlled environment"
label	var	d_c1_5b4	"High-end central storage facilities"
label	var	d_c1_5b5	"Continuous temperature monitoring device"

label	var	d_c1_6b1	"Manual packing "
label	var	d_c1_6b2	"Human-operated mechanical equipment "
label	var	d_c1_6b3	"Automated packing"
label	var	d_c1_6b4	"Modified atmosphere packing"



mata: mata clear

local i = 1

foreach var in $sbf_agriculture {

svy: reg `var' gender_management
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(unconditional) append(row`i') ctitles("", Difference) ///
 store(unconditional) note("")  bdec(2) 
 
svy: reg `var' gender_management i.country_code
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(conditional) append(row`i') ctitles("", Difference) ///
 store(conditional) note("")  bdec(2) 

	
svy: reg `var' gender_management i.country_code i.a5a i.size_group
outreg, keep(gender_management) rtitle("`: var label `var''") stats(b) ///
noautosumm store(row`i') starlevels(10 5 1) starloc(1)  bdec(2) 
outreg, replay(diff) append(row`i') ctitles("", Difference) ///
 store(diff) note("")  bdec(2) 

 
local ++i
}

outreg, replay(unconditional) merge(conditional)
outreg, replay(unconditional) merge(diff)

* Summary statistics

local count: word count $sbf_agriculture
mat sumstat = J(`count',4,.)

local i = 1

foreach var in $sbf_agriculture {

svy, subpop(Agriculture_Male): mean `var' 
estat sd
mat sumstat[`i',1] = r(mean) 
mat sumstat[`i',2] = r(sd)

svy, subpop(Agriculture_Female): mean `var' 
estat sd
mat sumstat[`i',3] = r(mean) 
mat sumstat[`i',4] = r(sd)
local i = `i' + 1

}

frmttable, statmat(sumstat) store(sumstat) sfmt(f,f,f,f) sdec(2)

outreg using "${path_output}/Tables/TableB3", ///
replay(sumstat) merge(unconditional) bdec(2) tex nocenter note("") fragment plain replace  ///
ctitles("", Male, "", "Female", "", ""\ "", Mean,  SD, Mean, SD, Uncond.,Cond.)  starlevels(10 5 1)

drop land irrigation pest harvesting storage packing 



**************************************************************************************************************************************************************************
****************************************************************** Summary statistics ************************************************************************************
**************************************************************************************************************************************************************************

*===============================================================================
* Table B1
*===============================================================================


global DESCVARS "lnvapw tot_emp_2019 mnc_group exp_group d2d d7b mq_index ownership incentives performance mhc_index college_manager a7a experience_lc studied_abroad innovation_skills_index share_college R_and_D develop"

est clear  // clear the stored estimates

estpost tabstat $DESCVARS [aw = $weight3], c(stat) s(mean median sd min max n)

ereturn list // list the stored locals

esttab using "${path_output}/Tables/TableB1", replace ////
cells("mean(fmt(%6.2fc)) p50(fmt(%6.2fc)) sd(fmt(%6.2fc)) min max count(fmt(%6.0fc))") nonumber  ///
  nomtitle nonote noobs label booktabs ///
  collabels("Mean" "Median" "SD" "Min" "Max" "N") ///
  eqlabels(none) 
  
