
*===============================================================================
* Figure 5
*===============================================================================

/*
1 = Other firms in the sector
2 = Other firms in the locality, but different sector
3 = Suppliers or buyers
4 = Industrial or trade associations
5 = Public technolgy extension services
6 = Private consultants 
7 = Fairs, events, and missions
*/

foreach num of numlist 1/7 {

gen d2a_`num' = 0	
replace d2a_`num' = 1 if d2a == `num'	

probit d2a_`num' gender_management i.a5a i.formality i.size_group i.country_code  [pw = $weight3]
}

probit d2a_1 gender_management i.a5a i.formality i.size_group i.country_code  [pw = $weight3]
estimates store A
probit d2a_2 gender_management i.a5a i.formality i.size_group i.country_code  [pw = $weight3]
estimates store B
probit d2a_3 gender_management i.a5a i.formality i.size_group i.country_code  [pw = $weight3]
estimates store C

coefplot A B C, keep(gender_management) yline(0) mlabel format(%9.2g) scheme(s2mono) graphregion(color(white)) ///
vertical /*rescale(100)*/ ytitle("Coefficient") coeflabels(gender_management = "FTM", notick) ///
legend(row(1) size(small) position(6) region(lcolor(black)) label(1 "Firms in the sector") label(3 "Firms another sector") label(5 "Suppliers or buyers") label(7 "Business associations")) ///
recast(bar) barwidth(0.1) ciopts(recast(rcap)) citop level(90) 
graph export "$path_output\Figures\Figure5.png", as(png) replace

*===============================================================================
* Figure 4
*===============================================================================

/*
d5d
1 = Universities
2 = Government agency
3 = Other local companies
4 = Foreign company
5 = Business associations
6 = Other sources
*/

foreach num of numlist 1/7 {

gen d5d_`num' = 0	if d5d != 0
replace d5d_`num' = 1 if d5d == `num'	& d5d != 0 

}


probit d5d_1 gender_management i.a5a i.formality i.size_group i.country_code [pw = $weight3]
estimates  store A
probit d5d_2 gender_management i.a5a i.formality i.size_group i.country_code [pw = $weight3]
estimates  store B
probit d5d_4 gender_management i.a5a i.formality i.size_group i.country_code [pw = $weight3]
estimates  store D
probit d5d_5 gender_management i.a5a i.formality i.size_group i.country_code [pw = $weight3]
estimates  store E

coefplot A B D E , keep(gender_management) yline(0) mlabel format(%9.2g) scheme(s2mono) graphregion(color(white))  ///
vertical /*rescale(100)*/ ytitle("Coefficient") coeflabels(gender_management = "FTM", notick) ///
legend(row(2) position(6) size(small) region(lcolor(black)) label(1 "Universities") label(3 "Government Agency") label(5 "Foreign Company") label(7 "Business associations")) ///
recast(bar) barwidth(0.1) ciopts(recast(rcap)) citop level(90) 
graph export "$path_output\Figures\Figure4.png", as(png) replace



************************************************************************************************************************************************************************************************** 
************************************ OLS - Explaining adoption between grops******************************************************
************************************************************************************************************************************************

*===============================================================================
* Table 10
*===============================================================================

*************************************************************
global categorical "mnc_group, exp_group, d2d, d7b, finance_constraint, formality"
*************************************************************

*keep if !missing($categorical)

foreach x of varlist mnc_group exp_group d2d d7b finance_constraint formality {

tab `x', gen(`x'_) nofreq
	
}

tab a5a, gen(sec_) nofreq
tab country, gen(ctr_) nofreq
tab region, gen(reg_) nofreq
tab size_group, gen(size_) nofreq

label var mnc_group_2 "Multinational"
label var exp_group_2 "Exporter"
label var d7b_2 "Government support"
label var d2d_2 "Interaction with MNEs"
label var finance_constraint_2 "Financial constraint"
label var formality_2 "Formality"

*************************************************************
global control_index "mq_index mhc_index innovation_skills_index"
*************************************************************

*************************************************************
global righthand "$control_index (Size: normalize(size_1 size_2 size_3))  (Multinational: normalize(mnc_group_1 mnc_group_2)) (Exporter:normalize(exp_group_1 exp_group_2)) (GovernmentSupport: normalize(d2d_1 d2d_2)) (InteractionMNEs: normalize(d7b_1 d7b_2)) (Sector:normalize(sec_1 sec_2 sec_3 sec_4 sec_5 sec_6 sec_7 sec_8 sec_9 sec_10 sec_11 sec_12 sec_13 sec_14)), by(gender_management) relax swap svy pooled"
*************************************************************

svy: reg tech_max_gbf_firm i.country_code
predict tech_max_gbf_firm_r, residuals

svy: reg tech_int_gbf_firm i.country_code
predict tech_int_gbf_firm_r, residuals

svy: reg tech_max_sbf_firm i.country_code
predict tech_max_sbf_firm_r, residuals

svy: reg tech_int_sbf_firm i.country_code
predict tech_int_sbf_firm_r, residuals

eststo reg01: oaxaca tech_max_gbf_firm_r $righthand

eststo reg02: oaxaca tech_int_gbf_firm_r $righthand

eststo reg03: oaxaca tech_max_sbf_firm_r $righthand

eststo reg04: oaxaca tech_int_sbf_firm_r $righthand

esttab reg01 reg02 reg03 reg04  using "${path_output}\Tables\Table10", replace b(3) se(3) f label booktabs alignment(S) eqlabels(none) stats(N, labels("Observations")) mgroups(, pattern(1 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) mtitles("GBF-EXT" "GBF-INT" "SBF-EXT" "SBF-INT") compress star(* 0.10 ** 0.05 *** 0.01) drop(_cons )



*===============================================================================
* Table B7 and B8
*===============================================================================


* Table B7

eststo reg01:svy:reg tech_max_gbf_firm_r i.gender_management mq_index mhc_index innovation_skills_index mnc_group exp_group d2d d7b i.finance_constraint i.formality i.size_group i.a5a 

eststo reg02:svy:reg tech_max_gbf_firm_r mq_index mhc_index innovation_skills_index mnc_group exp_group d2d d7b i.finance_constraint i.formality i.size_group i.a5a if gender_management == 0

eststo reg03:svy:reg tech_max_gbf_firm_r mq_index mhc_index innovation_skills_index mnc_group exp_group d2d d7b i.finance_constraint i.formality i.size_group i.a5a if gender_management == 1

eststo reg04:svy:reg tech_int_gbf_firm_r i.gender_management mq_index mhc_index innovation_skills_index mnc_group exp_group d2d d7b i.finance_constraint i.formality i.size_group i.a5a

eststo reg05:svy:reg tech_int_gbf_firm_r mq_index mhc_index innovation_skills_index mnc_group exp_group d2d d7b i.finance_constraint i.formality i.size_group i.a5a if gender_management == 0

eststo reg06:svy:reg tech_int_gbf_firm_r mq_index mhc_index innovation_skills_index mnc_group exp_group d2d d7b i.finance_constraint i.formality i.size_group i.a5a if gender_management == 1

qui estadd local sector "Yes": reg01 reg02 reg03 reg04 reg05 reg06 
qui estadd local country "Yes": reg01 reg02 reg03 reg04 reg05 reg06

esttab reg01 reg02 reg03 reg04 reg05 reg06 using "${path_output}\Tables\TableB7", star(* 0.10 ** 0.05 *** 0.01) replace f b se label booktabs alignment(S) eqlabels(none)  mtitles("GBF EXT" "GBF EXT" "GBF EXT" "GBF INT" "GBF INT" "GBF INT")  drop( *.a5a 0.formality ) stats(sector N r2, labels("Sector" "Observations" "R-squared"))  mgroups(, pattern(1 0 0 0 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))

* Table B8


eststo reg01:svy:reg tech_max_sbf_firm_r i.gender_management mq_index mhc_index innovation_skills_index mnc_group exp_group d2d d7b i.finance_constraint i.formality i.size_group i.a5a 

eststo reg02:svy:reg tech_max_sbf_firm_r mq_index mhc_index innovation_skills_index mnc_group exp_group d2d d7b i.finance_constraint i.formality i.size_group i.a5a if gender_management == 0

eststo reg03:svy:reg tech_max_sbf_firm_r mq_index mhc_index innovation_skills_index mnc_group exp_group d2d d7b i.finance_constraint i.formality i.size_group i.a5a if gender_management == 1

eststo reg04:svy:reg tech_int_sbf_firm_r  i.gender_management mq_index mhc_index innovation_skills_index mnc_group exp_group d2d d7b i.finance_constraint i.formality i.size_group i.a5a

eststo reg05:svy:reg tech_int_sbf_firm_r mq_index mhc_index innovation_skills_index mnc_group exp_group d2d d7b i.finance_constraint i.formality i.size_group i.a5a if gender_management == 0

eststo reg06:svy:reg tech_int_sbf_firm_r mq_index mhc_index innovation_skills_index mnc_group exp_group d2d d7b i.finance_constraint i.formality i.size_group i.a5a if gender_management == 1

qui estadd local sector "Yes": reg01 reg02 reg03 reg04 reg05 reg06 
qui estadd local country "Yes": reg01 reg02 reg03 reg04 reg05 reg06

esttab reg01 reg02 reg03 reg04 reg05 reg06 using "${path_output}\Tables\TableB8", star(* 0.10 ** 0.05 *** 0.01) replace f b se label booktabs alignment(S) eqlabels(none)  mtitles("SBF EXT" "SBF EXT" "SBF EXT" "SBF INT" "SBF INT" "SBF INT")  drop( *.a5a 0.formality ) stats(sector N r2, labels("Sector" "Observations" "R-squared"))  mgroups(, pattern(1 0 0 0 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
