

* We define two IVs: the share of FTM in the same sector-country and firms' female ownership
bysort sector_region: egen total = count(gender_management)
bysort sector_region: egen count_ftm = count(gender_management) if gender_management == 1
gen step_1 = (count_ftm)/(total)
bysort sector_region: egen share_ftm = max(step_1)
replace share_ftm = (count_ftm - 1)/(total - 1) if gender_management == 1
replace share_ftm = 0 if share_ftm == .

preserve
keep if Productivity == 1
**************************************************************************************************************************************************************************
************************************************************** Simulations ***********************************************************************************************
**************************************************************************************************************************************************************************

*===============================================================================
* Figure 3
*===============================================================================

gen technology_1 = tech_max_gbf_firm
gen technology_2 = tech_int_gbf_firm
gen technology_3 = tech_max_sbf_firm
gen technology_4 = tech_int_sbf_firm

label var technology_1  "GBF EXT"
label var technology_2  "GBF INT"
label var technology_3  "SBF EXT"
label var technology_4  "SBF INT"

gen technology_interaction_1 = tech_max_gbf_firm*share_ftm
gen technology_interaction_2 = tech_int_gbf_firm*share_ftm
gen technology_interaction_3 = tech_max_sbf_firm*share_ftm
gen technology_interaction_4 = tech_int_sbf_firm*share_ftm

gen ownership_interaction_1 = tech_max_gbf_firm*gender_ownership
gen ownership_interaction_2 = tech_int_gbf_firm*gender_ownership
gen ownership_interaction_3 = tech_max_sbf_firm*gender_ownership
gen ownership_interaction_4 = tech_int_sbf_firm*gender_ownership

gen gender_interaction_1 = tech_max_gbf_firm*gender_management
gen gender_interaction_2 = tech_int_gbf_firm*gender_management
gen gender_interaction_3 = tech_max_sbf_firm*gender_management
gen gender_interaction_4 = tech_int_sbf_firm*gender_management

label var gender_interaction_1 "FTM*GBF EXT"
label var gender_interaction_2 "FTM*GBF INT"
label var gender_interaction_3 "FTM*SBF EXT"
label var gender_interaction_4 "FTM*SBF INT"



ivregress 2sls lnvapw ln_cap_pw ln_tot_emp tech_int_gbf_firm i.a5a i.region formality mhc_index (i.gender_management c.tech_int_gbf_firm#i.gender_management = share_ftm gender_ownership c.tech_int_gbf_firm#c.share_ftm c.tech_int_gbf_firm#c.gender_ownership) [pw = $weight3], first robust	
margins gender_management [pw = $weight3], at(tech_int_gbf_firm =(1(0.5)5)) 
marginsplot, graphregion(color(white)) ytitle("Log(Labor Productivity)") xtitle("GBF - Intensive") title("") legend(order(2 "Female" 3 "Male" ))
graph export "${path_output}\Figures\Figure3c.png", as(png) name("Graph") replace

ivregress 2sls lnvapw ln_cap_pw ln_tot_emp tech_int_sbf_firm i.a5a i.region formality mhc_index (i.gender_management c.tech_int_sbf_firm#i.gender_management = share_ftm gender_ownership c.tech_int_sbf_firm#c.share_ftm c.tech_int_sbf_firm#c.gender_ownership) [pw = $weight3], first robust	
margins gender_management [pw = $weight3], at(tech_int_sbf_firm =(1(0.5)5))
marginsplot, graphregion(color(white)) ytitle("Log(Labor Productivity)") xtitle("SBF - Intensive") title("") legend(order(2 "Female" 3 "Male" ))
graph export "${path_output}\Figures\Figure3d.png", as(png) name("Graph") replace

svy: reg lnvapw i.gender_management##c.tech_int_gbf_firm ln_cap_pw ln_tot_emp i.a5a formality i.region mhc_index
quietly margins gender_management [pw = $weight3], at(tech_int_gbf_firm =(1(0.5)5)) 
marginsplot, graphregion(color(white)) ytitle("Log(Labor Productivity)")  xtitle("GBF - Intensive") title("") legend(order(2 "Female" 3 "Male" ))
graph export "${path_output}\Figures\Figure3a.png", as(png) name("Graph") replace

svy: reg lnvapw i.gender_management##c.tech_int_sbf_firm ln_cap_pw ln_tot_emp i.a5a formality i.region mhc_index
quietly margins gender_management [pw = $weight3], at(tech_int_sbf_firm =(1(0.5)5)) 
marginsplot, graphregion(color(white)) ytitle("Log(Labor Productivity)")  xtitle("SBF - Intensive") title("") legend(order(2 "Female" 3 "Male" ))
graph export "${path_output}\Figures\Figure3b.png", as(png) name("Graph") replace

**************************************************************************************************************************************************************************
************************************************************** OLS *******************************************************************************************************
**************************************************************************************************************************************************************************

*===============================================================================
* Table 6
*===============================================================================

restore
keep if Productivity == 1


foreach var of varlist tech_max_gbf_firm tech_max_sbf_firm tech_int_gbf_firm tech_int_sbf_firm {
	
sum `var' [aw = $weight3]
replace `var' = `var' - `r(mean)'	
	
}


* Sales per worker

gen sapw = sales/tot_emp
gen lnsapw = ln(sapw)

* Intermediate per worker

gen intpw =  mat_cost/tot_emp
gen lnintpw = ln(intpw)

label var lnsapw "Log(Sales per worker)"
label var ln_cap_pw "Log(Capital per worker)"
label var ln_lab_cost_pw "Log(Labor cost per worker)"
label var ln_tot_emp "Log(Employment)"
label var lnintpw "Log(Material per worker)"

*************************************************************
global control_index "i.a5a i.region formality mhc_index"
*************************************************************

eststo reg01:svy: reg lnvapw gender_management i.a5a i.region formality
eststo reg02:svy: reg lnvapw gender_management $control_index
eststo reg03:svy: reg lnvapw gender_management ln_cap_pw ln_tot_emp $control_index 
eststo reg04:svy: reg lnvapw gender_management ln_cap_pw ln_tot_emp tech_max_gbf_firm $control_index 
eststo reg05:svy: reg lnvapw gender_management ln_cap_pw ln_tot_emp tech_int_gbf_firm $control_index 
eststo reg06:svy: reg lnvapw gender_management ln_cap_pw ln_tot_emp tech_max_sbf_firm $control_index 
eststo reg07:svy: reg lnvapw gender_management ln_cap_pw ln_tot_emp tech_int_sbf_firm $control_index 


qui estadd local sector "Yes": reg01 reg02 reg03 reg04 reg05 reg06 reg07 
qui estadd local country "Yes": reg01 reg02 reg03 reg04 reg05 reg06 reg07 

esttab reg01 reg02 reg03 reg04 reg05 reg06 reg07 using "${path_output}\Tables\Table6", star(* 0.10 ** 0.05 *** 0.01) replace f b se label booktabs alignment(S) eqlabels(none)  mtitles("Ln(VAPW)" "Ln(VAPW)" "Ln(VAPW)" "Ln(VAPW)" "Ln(VAPW)" "Ln(VAPW)" "Ln(VAPW)" "Ln(VAPW)")   order(gender_management ln_cap_pw ln_tot_emp tech_max_gbf_firm tech_int_gbf_firm tech_max_sbf_firm tech_int_sbf_firm) drop(*.region *.a5a) stats(sector country N r2, labels("Sector" "Region" "Observations" "R-squared"))  mgroups(, pattern(1 0 0 0 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))

**************************************************************************************************************************************************************************
************************************************************** OLS - Interaction *****************************************************************************************
**************************************************************************************************************************************************************************

*===============================================================================
* Table 8
*===============================================================================

gen gender_interaction_1 = tech_max_gbf_firm*gender_management
gen gender_interaction_2 = tech_int_gbf_firm*gender_management
gen gender_interaction_3 = tech_max_sbf_firm*gender_management
gen gender_interaction_4 = tech_int_sbf_firm*gender_management

label var gender_interaction_1 "FTM*GBF EXT"
label var gender_interaction_2 "FTM*GBF INT"
label var gender_interaction_3 "FTM*SBF EXT"
label var gender_interaction_4 "FTM*SBF INT"


eststo reg01:svy: reg lnvapw gender_management ln_cap_pw ln_tot_emp tech_max_gbf_firm gender_interaction_1 $control_index 
eststo reg02:svy: reg lnvapw gender_management ln_cap_pw ln_tot_emp tech_int_gbf_firm gender_interaction_2 $control_index 
eststo reg03:svy: reg lnvapw gender_management ln_cap_pw ln_tot_emp tech_max_sbf_firm gender_interaction_3 $control_index 
eststo reg04:svy: reg lnvapw gender_management ln_cap_pw ln_tot_emp tech_int_sbf_firm gender_interaction_4 $control_index 


qui estadd local sector "Yes": reg01 reg02 reg03 reg04
qui estadd local country "Yes": reg01 reg02 reg03 reg04

esttab reg01 reg02 reg03 reg04 using "${path_output}\Tables\Table8", star(* 0.10 ** 0.05 *** 0.01) replace f b se label booktabs alignment(S) eqlabels(none)  mtitles("Ln(VAPW)" "Ln(VAPW)" "Ln(VAPW)" "Ln(VAPW)") order(gender_management tech_max_gbf_firm gender_interaction_1 tech_int_gbf_firm gender_interaction_2 tech_max_sbf_firm gender_interaction_3 tech_int_sbf_firm gender_interaction_4) keep(gender_management tech_max_gbf_firm tech_int_gbf_firm tech_max_sbf_firm tech_int_sbf_firm gender_interaction_*) stats(sector country N r2, labels("Sector" "Region" "Observations" "R-squared"))  mgroups(, pattern(1 0 0 0 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))


**************************************************************************************************************************************************************************
******************************************************************************* 2SLS ************************************************************************************
**************************************************************************************************************************************************************************

*===============================================================================
* Table 7
*===============================================================================


eststo reg01: ivregress 2sls lnvapw i.a5a i.region formality (gender_management = gender_ownership share_ftm) [pw = $weight3], first robust
estat firststage
mat fstat = r(singleresults)
estadd scalar fs = fstat[1,4] 
estat overid,forceweights 
mat ovride_lnvapw1 =  r(p_score)
estadd scalar J = ovride_lnvapw1[1,1] : reg01

eststo reg02: ivregress 2sls lnvapw $control_index ln_cap_pw  ln_tot_emp (gender_management = gender_ownership share_ftm) [pw = $weight3], first robust
estat firststage
mat fstat = r(singleresults)
estadd scalar fs = fstat[1,4] 
estat overid,forceweights 
mat ovride_lnvapw2 =  r(p_score)
estadd scalar J = ovride_lnvapw2[1,1] : reg02

eststo reg03: ivregress 2sls lnvapw $control_index ln_cap_pw ln_tot_emp tech_max_gbf_firm (gender_management = gender_ownership share_ftm) [pw = $weight3], first robust
estat firststage
mat fstat = r(singleresults)
estadd scalar fs = fstat[1,4] 
estat overid,forceweights 
mat ovride_lnvapw3 =  r(p_score)
estadd scalar J = ovride_lnvapw3[1,1] : reg03

eststo reg04: ivregress 2sls lnvapw $control_index ln_cap_pw ln_tot_emp tech_int_gbf_firm (gender_management = gender_ownership share_ftm) [pw = $weight3], first robust
estat firststage
mat fstat = r(singleresults)
estadd scalar fs = fstat[1,4] 
estat overid,forceweights 
mat ovride_lnvapw4 =  r(p_score)
estadd scalar J = ovride_lnvapw4[1,1] : reg04

eststo reg05: ivregress 2sls lnvapw $control_index ln_cap_pw ln_tot_emp tech_max_sbf_firm (gender_management = gender_ownership share_ftm) [pw = $weight3], first robust
estat firststage
mat fstat = r(singleresults)
estadd scalar fs = fstat[1,4] 
estat overid,forceweights 
mat ovride_lnvapw5 =  r(p_score)
estadd scalar J = ovride_lnvapw5[1,1] : reg05

eststo reg06: ivregress 2sls lnvapw $control_index ln_cap_pw ln_tot_emp tech_int_sbf_firm (gender_management = gender_ownership share_ftm) [pw = $weight3], first robust
estat firststage
mat fstat = r(singleresults)
estadd scalar fs = fstat[1,4] 
estat overid,forceweights 
mat ovride_lnvapw6 =  r(p_score)
estadd scalar J = ovride_lnvapw6[1,1] : reg06

eststo reg07: ivregress 2sls lnvapw $control_index (gender_management = gender_ownership share_ftm) [pw = $weight3], first robust
estat firststage
mat fstat = r(singleresults)
estadd scalar fs = fstat[1,4] 
estat overid,forceweights 
mat ovride_lnvapw7 =  r(p_score)
estadd scalar J = ovride_lnvapw7[1,1] : reg07


qui estadd local sector "Yes": reg01 reg02 reg03 reg04 reg05 reg06 reg07 
qui estadd local country "Yes": reg01 reg02 reg03 reg04 reg05 reg06 reg07 

mat J = (ovride_lnvapw1, ovride_lnvapw7, ovride_lnvapw2, ovride_lnvapw3, ovride_lnvapw4, ovride_lnvapw5, ovride_lnvapw6)
estadd matrix J, replace

esttab reg01 reg07 reg02 reg03 reg04 reg05 reg06 using "${path_output}\Tables\Table7", star(* 0.10 ** 0.05 *** 0.01) replace f b se label booktabs alignment(S) eqlabels(none)  mtitles("Ln(VAPW)" "Ln(VAPW)" "Ln(VAPW)") order(gender_management ln_cap_pw ln_tot_emp tech_max_gbf_firm tech_int_gbf_firm tech_max_sbf_firm tech_int_sbf_firm)  drop(*.region *.a5a) stats(sector country N r2 fs J, labels("Sector" "Region" "Observations" `"\(R^{2}\)"' `"\(F\)"' `"\(J\)"' ))  mgroups(, pattern(1 0 0 0 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))

**************************************************************************************************************************************************************************
******************************************************************************* 2SLS INTERACTION *************************************************************************
**************************************************************************************************************************************************************************

*===============================================================================
* Table 9
*===============================================================================


gen technology_1 = tech_max_gbf_firm
gen technology_2 = tech_int_gbf_firm
gen technology_3 = tech_max_sbf_firm
gen technology_4 = tech_int_sbf_firm

label var technology_1  "GBF EXT"
label var technology_2  "GBF INT"
label var technology_3  "SBF EXT"
label var technology_4  "SBF INT"

gen technology_interaction_1 = tech_max_gbf_firm*share_ftm
gen technology_interaction_2 = tech_int_gbf_firm*share_ftm
gen technology_interaction_3 = tech_max_sbf_firm*share_ftm
gen technology_interaction_4 = tech_int_sbf_firm*share_ftm

gen ownership_interaction_1 = tech_max_gbf_firm*gender_ownership
gen ownership_interaction_2 = tech_int_gbf_firm*gender_ownership
gen ownership_interaction_3 = tech_max_sbf_firm*gender_ownership
gen ownership_interaction_4 = tech_int_sbf_firm*gender_ownership

label var gender_interaction_1 "FTM*GBF EXT"
label var gender_interaction_2 "FTM*GBF INT"
label var gender_interaction_3 "FTM*SBF EXT"
label var gender_interaction_4 "FTM*SBF INT"


foreach num of numlist 1/4 {
	
eststo iv_`num': ivregress 2sls lnvapw ln_cap_pw ln_tot_emp  technology_`num'  i.region i.a5a i.formality mhc_index (gender_management gender_interaction_`num' = share_ftm gender_ownership technology_interaction_`num' ownership_interaction_`num') [pw = $weight3], first robust	
	
estat firststage
mat fstat = r(multiresults)
estadd scalar fs_1 = fstat[1,2] : iv_`num'
estadd scalar fs_2 = fstat[2,2] : iv_`num'

estat overid, forceweights 
mat ovride_`num' =  r(p_score)
estadd scalar J = ovride_`num'[1,1] : iv_`num'

}

mat A = (ovride_1, ovride_2, ovride_3, ovride_4)
estadd matrix J, replace

qui estadd local controls "Yes": iv_1 iv_2 iv_3 iv_4 
qui estadd local sector "Yes": iv_1 iv_2 iv_3 iv_4 
qui estadd local region "Yes": iv_1 iv_2 iv_3 iv_4 

esttab iv_1 iv_2 iv_3 iv_4 using "${path_output}\Tables\Table9", star(* 0.10 ** 0.05 *** 0.01) replace f b se label booktabs alignment(S) eqlabels(none)  mtitles("Productivity" "Productivity" "Productivity" "Productivity") order(gender_management ln_cap_pw ln_tot_emp  technology_1 gender_interaction_1 technology_2 gender_interaction_2 technology_3 gender_interaction_3 technology_4 gender_interaction_4) keep(gender_management technology_1 gender_interaction_1 technology_2 gender_interaction_2 technology_3 gender_interaction_3 technology_4 gender_interaction_4) stats(controls sector region N r2 fs_1 fs_2 J, labels("Controls" "Sector"  "Region" "Observations" `"\(R^{2}\)"' "Shea's R-squared" "Shea's R-squared" `"\(J\)"' ))  mgroups(, pattern(1 0 0 0 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))

**************************************************************************************************************************************************************************
******************************************************************************* PSM ************************************************************************************
**************************************************************************************************************************************************************************

*===============================================================================
* Table D1
*===============================================================================


gen random = runiform()
sort random

psmatch2 gender_management ln_cap_pw ln_tot_emp  $control_index,  out(lnvapw) neighbor(1)  caliper(0.1) common ate  noreplacement
matrix ATT_1 = ( 0\ r(att) \ r(seatt) ) 
psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index, out(lnvapw) common ate  kernel k(biweight)
matrix ATT_2 = ( 0\ r(att) \ r(seatt) )
psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index,  out(lnvapw) radius  caliper(0.1) common ate  noreplacement
matrix ATT_3 = ( 0\ r(att) \ r(seatt) )

psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index,  out(tech_max_gbf_firm) neighbor(1)  caliper(0.1) common ate  noreplacement
matrix ATT_4 = ( 0\ r(att) \ r(seatt) )
psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index,  out(tech_max_gbf_firm) common ate  kernel k(biweight)
matrix ATT_5 = ( 0\ r(att) \ r(seatt) )
psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index,  out(tech_max_gbf_firm) radius  caliper(0.1) common ate  noreplacement
matrix ATT_6 = ( 0\ r(att) \ r(seatt) )

psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index,  out(tech_int_gbf_firm) neighbor(1)  caliper(0.1) common ate  noreplacement
matrix ATT_7 = ( 0\ r(att) \ r(seatt) )
psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index,  out(tech_int_gbf_firm) common ate  kernel k(biweight)
matrix ATT_8 = ( 0\ r(att) \ r(seatt) )
psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index,  out(tech_int_gbf_firm) radius  caliper(0.1) common ate  noreplacement
matrix ATT_9 = (0\  r(att) \ r(seatt) )

psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index,  out(tech_max_sbf_firm) neighbor(1)  caliper(0.1) common ate  noreplacement
matrix ATT_10 = (0\  r(att) \ r(seatt) )
psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index,  out(tech_max_sbf_firm) common ate  kernel k(biweight)
matrix ATT_11 = (0\  r(att) \ r(seatt) )
psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index,  out(tech_max_sbf_firm) radius  caliper(0.1) common ate  noreplacement
matrix ATT_12 = (0\  r(att) \ r(seatt) )

psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index,  out(tech_int_sbf_firm) neighbor(1)  caliper(0.1) common ate  noreplacement
matrix ATT_13 = (0\  r(att) \ r(seatt) )
psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index,  out(tech_int_sbf_firm) common ate  kernel k(biweight)
matrix ATT_14 = (0\  r(att) \ r(seatt) )
psmatch2 gender_management ln_cap_pw ln_tot_emp $control_index,  out(tech_int_sbf_firm) radius  caliper(0.1) common ate  noreplacement
matrix ATT_15 = ( 0\ r(att) \ r(seatt) )

mat ATT = (ATT_1, ATT_2, ATT_3) \ (ATT_4, ATT_5, ATT_6) \ (ATT_7, ATT_8, ATT_9) \ (ATT_10, ATT_11, ATT_12) \ (ATT_13, ATT_14, ATT_15)
mat colnames ATT = "Nearest" "Kernel" "Radius"
mat rownames ATT ="Productivity" "ATT" "SE" "GBF Ext" "ATT" "SE" "GBF Int" "ATT" "SE" "SBF Ext" "ATT" "SE" "SBF Int" "ATT" "SE" 

esttab matrix(ATT) using "${path_output}\Tables\TableD1", star(* 0.10 ** 0.05 *** 0.01) replace f b se label booktabs alignment(S) eqlabels(none)  mtitles("Productivity" "GBF Ext" "GBF Int" "SBF Ext" "SBF Int") mgroups(, pattern(1 0 0 0 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))

**************************************************************************************************************************************************************************
******************************************************************************* OLS estimates by country *****************************************************************
**************************************************************************************************************************************************************************

*===============================================================================
* Table D2
*===============================================================================

keep if Productivity == 1

*************************************************************
global control_index "i.a5a formality mhc_index"
*************************************************************

levelsof country, local(country_A)


foreach var of local country_A {
	
    eststo reg01_`var':svy: reg lnvapw gender_management ln_cap_pw ln_tot_emp tech_max_gbf_firm gender_interaction_1 $control_index if country == "`var'"
	matrix b1_`var' = ( 0\ _b[gender_interaction_1] \ _se[gender_interaction_1])
    eststo reg02_`var':svy: reg lnvapw gender_management ln_cap_pw ln_tot_emp tech_int_gbf_firm gender_interaction_2 $control_index if country == "`var'"
	matrix b2_`var' = ( 0\ _b[gender_interaction_2] \ _se[gender_interaction_2])
	eststo reg03_`var':svy: reg lnvapw gender_management ln_cap_pw ln_tot_emp tech_max_sbf_firm gender_interaction_3 $control_index if country == "`var'"
	matrix b3_`var' = ( 0\ _b[gender_interaction_3] \ _se[gender_interaction_3])
    eststo reg04_`var':svy: reg lnvapw gender_management ln_cap_pw ln_tot_emp tech_int_sbf_firm gender_interaction_4 $control_index if country == "`var'"
	matrix b4_`var' = ( 0\ _b[gender_interaction_4] \ _se[gender_interaction_4])
}

mat ATT = (b1_Brazil, b2_Brazil, b3_Brazil, b4_Brazil) \ (b1_Ethiopia, b2_Ethiopia, b3_Ethiopia, b4_Ethiopia) \ ///
 (b1_Georgia, b2_Georgia, b3_Georgia, b4_Georgia) \  (b1_Ghana, b2_Ghana, b3_Ghana, b4_Ghana) \ (b1_Kenya, b2_Kenya, b3_Kenya, b4_Kenya) ///
 \ (b1_Korea, b2_Korea, b3_Korea, b4_Korea) \ (b1_Senegal, b2_Senegal, b3_Senegal, b4_Senegal)  \ (b1_Vietnam, b2_Vietnam, b3_Vietnam, b4_Vietnam)
mat colnames ATT = "GBF Ext" "GBF Int" "SBF Ext" "SBF Int"
mat rownames ATT = "Brazil" "Beta" "SE" "Ethiopia" "Beta" "SE" "Georgia" "Beta" "SE" "Ghana" "Beta" "SE" "Kenya" "Beta" "SE" "Korea" "Beta" "SE" "Senegal" "Beta" "SE" "Vietnam" "Beta" "SE"

esttab matrix(ATT) using "${path_output}\Tables\TableD2", star(* 0.10 ** 0.05 *** 0.01) replace f b se label booktabs alignment(S) eqlabels(none)  mtitles("GBF Ext" "GBF Int" "SBF Ext" "SBF Int") mgroups(, pattern(1 0 0 0 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))

